@@ -32,7 +32,7 @@
 #include "got_lib_delta.h"
 #include "got_lib_inflate.h"
 #include "got_lib_object.h"
-#include "got_lib_sha1.h"
+#include "got_lib_object_parse.h"
 
 #ifndef nitems
 #define nitems(_a) (sizeof(_a) / sizeof((_a)[0]))
@@ -228,8 +228,6 @@ static const struct got_error got_errors[] = {
 	{ GOT_ERR_BAD_TAG_SIGNATURE, "invalid tag signature" },
 	{ GOT_ERR_VERIFY_TAG_SIGNATURE, "cannot verify signature" },
 	{ GOT_ERR_SIGNING_TAG, "unable to sign tag" },
-	{ GOT_ERR_COMMIT_REDUNDANT_AUTHOR, "specified author is equal to the "
-	    "default one"},
 	{ GOT_ERR_BAD_QUERYSTRING, "invalid query string" },
 	{ GOT_ERR_INTEGRATE_BRANCH, "will not integrate into a reference "
 	    "outside the \"refs/heads/\" reference namespace" },
@@ -376,11 +374,11 @@ got_ferror(FILE *f, int code)
 const struct got_error *
 got_error_no_obj(struct got_object_id *id)
 {
-	char msg[sizeof("object   not found") + SHA1_DIGEST_STRING_LENGTH];
-	char id_str[SHA1_DIGEST_STRING_LENGTH];
+	char id_str[GOT_OBJECT_ID_HEX_MAXLEN];
+	char msg[sizeof("object   not found") + sizeof(id_str)];
 	int ret;
 
-	if (!got_sha1_digest_to_str(id->sha1, id_str, sizeof(id_str)))
+	if (!got_object_id_hex(id, id_str, sizeof(id_str)))
 		return got_error(GOT_ERR_NO_OBJ);
 
 	ret = snprintf(msg, sizeof(msg), "object %s not found", id_str);
@@ -390,6 +388,24 @@ got_error_no_obj(struct got_object_id *id)
 	return got_error_msg(GOT_ERR_NO_OBJ, msg);
 }
 
+const struct got_error *
+got_error_checksum(struct got_object_id *id)
+{
+	char id_str[GOT_OBJECT_ID_HEX_MAXLEN];
+	char msg[sizeof("checksum failure for object ") + sizeof(id_str)];
+	int ret;
+
+	if (!got_object_id_hex(id, id_str, sizeof(id_str)))
+		return got_error(GOT_ERR_OBJ_CSUM);
+
+	ret = snprintf(msg, sizeof(msg), "checksum failure for object %s",
+	    id_str);
+	if (ret < 0 || (size_t)ret >= sizeof(msg))
+		return got_error(GOT_ERR_OBJ_CSUM);
+
+	return got_error_msg(GOT_ERR_OBJ_CSUM, msg);
+}
+
 const struct got_error *
 got_error_not_ref(const char *refname)
 {
