@@ -16,6 +16,13 @@
 
 struct got_pathlist_head;
 
+/*
+ * Write the string representation fo an object ID in the given buffer.
+ * This buffer must be at least GOT_OBJECT_ID_HEX_MAXLEN bytes in size.
+ * The output depneds on the hash function used by the repository format.
+ */
+char *got_object_id_hex(struct got_object_id *, char *, size_t);
+
 const struct got_error *got_object_qid_alloc_partial(struct got_object_qid **);
 struct got_commit_object *got_object_commit_alloc_partial(void);
 struct got_tree_entry *got_alloc_tree_entry_partial(void);
