@@ -22,7 +22,6 @@
 #include <event.h>
 #include <poll.h>
 #include <limits.h>
-#include <sha1.h>
 #include <stdio.h>
 #include <stdint.h>
 #include <stdlib.h>
@@ -35,11 +34,12 @@
 #include "got_path.h"
 #include "got_version.h"
 #include "got_reference.h"
+#include "got_object.h"
 
 #include "got_lib_pkt.h"
 #include "got_lib_dial.h"
 #include "got_lib_gitproto.h"
-#include "got_lib_sha1.h"
+#include "got_lib_hash.h"
 #include "got_lib_poll.h"
 
 #include "gotd.h"
@@ -221,17 +221,11 @@ static const struct got_error *
 send_zero_refs(int outfd, int client_is_reading, int chattygot)
 {
 	const struct got_error *err = NULL;
+	const char *line = GOT_SHA1_STRING_ZERO " capabilities^{}";
 	char buf[GOT_PKT_MAX];
-	uint8_t zero[SHA1_DIGEST_LENGTH];
-	char hex[SHA1_DIGEST_STRING_LENGTH];
 	size_t len, capalen = 0;
 
-	memset(&zero, 0, sizeof(zero));
-
-	if (got_sha1_digest_to_str(zero, hex, sizeof(hex)) == NULL)
-		return got_error(GOT_ERR_BAD_OBJ_ID);
-
-	len = snprintf(buf, sizeof(buf), "%s capabilities^{}", hex);
+	len = strlcpy(buf, line, sizeof(buf));
 	if (len >= sizeof(buf))
 		return got_error(GOT_ERR_NO_SPACE);
 
@@ -438,7 +432,7 @@ parse_want_line(char **common_capabilities, uint8_t *id, char *buf, size_t len)
 	if (err)
 		return err;
 
-	if (!got_parse_sha1_digest(id, id_str)) {
+	if (!got_parse_hash_digest(id, id_str, GOT_HASH_SHA1)) {
 		err = got_error_msg(GOT_ERR_BAD_PACKET,
 		    "want-line with bad object ID");
 		goto done;
@@ -467,7 +461,7 @@ parse_have_line(uint8_t *id, char *buf, size_t len)
 	if (err)
 		return err;
 
-	if (!got_parse_sha1_digest(id, id_str)) {
+	if (!got_parse_hash_digest(id, id_str, GOT_HASH_SHA1)) {
 		err = got_error_msg(GOT_ERR_BAD_PACKET,
 		    "have-line with bad object ID");
 		goto done;
@@ -1054,8 +1048,8 @@ parse_ref_update_line(char **common_capabilities, char **refname,
 	if (err)
 		return err;
 
-	if (!got_parse_sha1_digest(old_id, old_id_str) ||
-	    !got_parse_sha1_digest(new_id, new_id_str)) {
+	if (!got_parse_hash_digest(old_id, old_id_str, GOT_HASH_SHA1) ||
+	    !got_parse_hash_digest(new_id, new_id_str, GOT_HASH_SHA1)) {
 		err = got_error_msg(GOT_ERR_BAD_PACKET,
 		    "ref-update with bad object ID");
 		goto done;
